@@ -1049,6 +1049,7 @@ thumbnail_path (const char                *uri,
   path = g_build_filename (g_get_user_cache_dir (),
                            "thumbnails",
                            size == GNOME_DESKTOP_THUMBNAIL_SIZE_LARGE ? "large" : "normal",
+                           file,
                            NULL);
   g_free (file);
   return path;
@@ -1500,7 +1501,7 @@ save_thumbnail (GdkPixbuf  *pixbuf,
 
   dirname = g_path_get_dirname (path);
 
-  if (!g_mkdir_with_parents (dirname, 0700))
+  if (g_mkdir_with_parents (dirname, 0700) != 0)
     goto out;
 
   tmp_path = g_strconcat (path, ".XXXXXX", NULL);
